<?php

function beverly_setup() {
	load_theme_textdomain( 'Beverly', get_template_directory() . '/languages' );
	if ( ! isset( $content_width ) ) $content_width = 900;
	add_theme_support('post-thumbnails'); 
	add_theme_support('post-formats', array('aside', 'gallery','link','quote', 'audio','video'));
	add_theme_support('admin-bar', array('callback'=>'__return_false'));
	add_theme_support('custom-background',array('default-color'=>'#CCC'));
	add_theme_support('automatic-feed-links');
	add_editor_style( array( 'css/editor-style.css', 'fonts/genericons.css', beverly_fonts_url() ) );
	register_nav_menu('left-menu',__('Left Sidebar Menu'));
	add_option('beverly_def_val', array('show_title'=>true, 'show_excerpt'=>true, 'show_author'=>true, 'show_tags'=>true, 'show_category'=>true, 'show_media'=>true, 'show_comments'=>true, 'show_pubdate'=>true));
}

function beverly_admin_pages() {
	add_theme_page( __('Default values', 'Beverly') , __('Default values', 'Beverly'), 'manage_options', 'beverly_def_val', 'beverly_def_val_page_callback');
	add_theme_page(__('Theme settings','Beverly'), __('Theme settings','Beverly'), 'manage_options', 'beverly_settings', 'beverly_settings_page_callback');
}

function beverly_register_fields() {
	register_setting('beverly_def_val', 'beverly_def_val', 'beverly_sanitize_array' );
	add_settings_section('beverly_def_val', __('Default values of new post', 'Beverly'), 'beverly_def_val_info_callback', 'beverly_def_val');
	add_settings_field('beverly_def_val_checkboxes', __('Show','Beverly'), 'beverly_def_val_checkboxes_callback', 'beverly_def_val', 'beverly_def_val');

	register_setting('beverly_main_settings', 'beverly_main_settings', 'beverly_sanitize_codes');
	add_settings_section('beverly_main_settings', __('Main Settings', 'Beverly'), '', 'beverly_settings');
	add_settings_field('favicon_url_input', __('Favicon url', 'Beverly'), 'beverly_favicon_callback', 'beverly_settings', 'beverly_main_settings');
	add_settings_field('own_styles', __('Own CSS Styles', 'Beverly'), 'beverly_own_styles_callback', 'beverly_settings', 'beverly_main_settings');
	add_settings_field('own_script', sprintf('%s <br/><small><i>%s</i></small>', __('Own JS Script', 'Beverly'),__('jQuery enabled', 'Beverly')), 'beverly_own_script_callback', 'beverly_settings', 'beverly_main_settings');

	register_setting('beverly_graphic_settings', 'beverly_graphic_settings', 'beverly_sanitize_array' );
	add_settings_section('beverly_graphic_settings', __('Graphic Settings', 'Beverly'), '', 'beverly_settings');
}

function beverly_favicon() {
	$favicon_url = get_option('beverly_main_settings')['favicon_url'];
	if(!empty($favicon_url)) { ?>
		<!-- favicon links -->
		<link rel="icon" href="<?php echo $favicon_url ?>" type="image/x-icon" />
		<link rel="shortcut icon" href="<?php echo $favicon_url ?>" type="image/x-icon" />
		<link rel="apple-touch-icon" href="<?php echo $favicon_url ?>" />
		<link rel="apple-touch-icon-precomposed" href="<?php echo $favicon_url ?>" />
		<!-- / favicon links -->
	<?php }
}

function beverly_custom_boxes() {
	$screens = array('post');
	foreach ( $screens as $screen ) {
		add_meta_box(
			'custom-excerpt',
			__( 'Custom Post Excerpt', 'Beverly' ),
			'beverly_custom_excerpt_box',
			$screen
		);
	}
}

function beverly_save_postdata($post_id) {
	$card_info = beverly_get_post_parts();
	if(!isset($_POST["is_post_form"]) && $card_info) return;
	if($card_info) {
		$card_info = array('show_title'=>false, 'show_excerpt'=>false, 'show_author'=>false, 'show_tags'=>false, 'show_category'=>false, 'show_media'=>false, 'show_comments'=>false, 'show_pubdate'=>false);
	} else {
		$card_info = get_option('beverly_def_val');
	}
	if(sanitize_text_field($_POST['title'])) $card_info['show_title'] = true;
	if(sanitize_text_field($_POST['post_excerpt_x'])) $card_info['show_excerpt'] = true;
	if(sanitize_text_field($_POST['author'])) $card_info['show_author'] = true;
	if(sanitize_text_field($_POST['tags'])) $card_info['show_tags'] = true;
	if(sanitize_text_field($_POST['pubdate'])) $card_info['show_pubdate'] = true;
	if(sanitize_text_field($_POST['media'])) $card_info['show_media'] = true;
	if(sanitize_text_field($_POST['category'])) $card_info['show_category'] = true;
	if(sanitize_text_field($_POST['comments'])) $card_info['show_comments'] = true;
	update_post_meta( $post_id, 'card_info', $card_info );
}

function beverly_customize_register($wp_customize) {
	$colors = array();
	$colors[] = array( 'slug'=>'anchor_color', 'default' => '#2183c4', 'label' => __( 'Anchor color', 'Beverly' ) );
	$colors[] = array( 'slug'=>'menu_anchor_color', 'default' => '#2183c4', 'label' => __( 'Anchor color in menu', 'Beverly' ) );
	foreach($colors as $color) {
		$wp_customize->add_setting( $color['slug'], array( 'default' => $color['default'], 'type' => 'option', 'capability' => 'edit_theme_options', 'transport' => 'refresh'));
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $color['slug'], array( 'label' => $color['label'], 'section' => 'colors', 'settings' => $color['slug'] )));
	}
}

function beverly_customize_css() {
	$sticky_count = beverly_get_sticky_count();
	$sticky_count = ($sticky_count > 6 ? 6 : $sticky_count);
	$column_count = ($sticky_count > 1 ? 2 : 1);
	$anchor_color = get_option('anchor_color','#2183c4');
	$menu_anchor_color = get_option('menu_anchor_color','#2183c4'); 
	?>
	<!-- custom css -->
	<style type="text/css">
		nav a {color:<?php echo $menu_anchor_color;?>;}
		nav a:focus{outline-color:<?php echo $menu_anchor_color; ?>}
		a, .post-title a:hover,.comment-author a:hover {color:<?php echo $anchor_color;?>;}
		.tags li a:hover, #new-post-slide, .post-content ins,.post-content mark {background-color:<?php echo $anchor_color;?>;}
		.tags li a:hover:after{border-left-color:<?php echo $anchor_color; ?>;}
		a:focus,input:focus, button:focus {outline-color:<?php echo $anchor_color;?>;}
		::selection {background-color:<?php echo $anchor_color;?>;}
		::-moz-selection{background-color:<?php echo $anchor_color;?>;}
		input:focus, textarea:focus, abbr[title], acronym[title] {border-color:<?php echo $anchor_color;?>;}
		@keyframes targetHighlight{from {background-color: <?php echo $anchor_color;?>;}to{background-color: #FFF;}}
		@-webkit-keyframes targetHighlight{from {background-color: <?php echo $anchor_color;?>;}to {background-color: #FFF;}}
		.post-content thead tr,.post-content th{background-color:<?php echo $anchor_color;?> !important;}
		.post-content tfoot,.comment.bypostauthor {border-top-color:<?php echo $anchor_color; ?>;}
		@media (min-width:525px) and (max-width:1000px) {
			#sticky-right-box {column-count:<?php echo $column_count ?>;
			-moz-column-count:<?php echo $column_count ?>;
			-webkit-column-count:<?php echo $column_count ?>;}
			#sticky-right-box .sticky:nth-of-type(<?php echo(ceil($sticky_count/2)+1);?>)<?php if($sticky_count % 2 == 0) echo ',#sticky-right-box .sticky:nth-of-type('.($sticky_count+1).')'; ?> {border-bottom:none;}
		}
		@media print {
			body:before {content:"<?php bloginfo("name"); ?>";}
		}
	</style><!-- / custom css -->
<?php }

function beverly_open_graph() {
	echo '<!-- open graph meta -->';
	$post = get_post();
	$og_title = wp_title('-', false);
	$og_site_name = get_bloginfo('name');
	$og_url = beverly_get_cur_url();
	$og_type = "website";
	$og_description = get_bloginfo('description');
	if( is_singular() ) {
		$og_imgs = beverly_get_first_n_imgs(3, true);
		if(has_post_thumbnail()) $og_imgs[0] = wp_get_attachment_image_src(get_post_thumbnail_id(), 'thumbnail')[0];
		$og_type = "article";
		$og_description = wp_trim_words(get_the_content());
		?>
		<?php foreach($og_imgs as $og_img) { ?>
			<meta property = "og:image" content = "<?php echo $og_img; ?>">
		<?php }?>
			<meta property = "article:published_time" content = "<?php echo $post->post_date; ?>">
			<meta property = "article:modified_time" content = "<?php echo $post->post_modified; ?>">
		<?php
	}
	?>
	<meta property="og:title" content="<?php echo $og_title; ?>" />
	<meta property="og:description" content="<?php echo $og_description; ?>" />
	<meta property="og:type" content="<?php echo $og_type; ?>" />
	<meta property="og:url" content="<?php echo $og_url; ?>" />
	<meta property="og:site_name" content="<?php echo $og_site_name; ?>" />
	<!-- / open graph meta -->
<?php } 

function beverly_msapplication() { ?>
	<!-- msApplication meta -->
	<meta name="application-name" content="<?php bloginfo('name'); ?>"/>
	<meta name="msapplication-TileColor" content="<?php echo '#'.beverly_get_full_hex_color(get_background_color()); ?>"/>
	<meta name="msapplication-notification" content="frequency=30;polling-uri=http://notifications.buildmypinnedsite.com/?feed=<?php bloginfo('rss2_url'); ?>&amp;id=1;polling-uri2=http://notifications.buildmypinnedsite.com/?feed=<?php bloginfo('comments_rss2_url'); ?>&amp;id=2; cycle=1"/>
	<!-- / msApplication meta -->
<?php }

function beverly_widgets_init() {
	register_sidebar(array(
		'name'          => __( 'Left Sidebar Area', 'Beverly' ),
		'id'            => 'left-sidebar-area',
		'description'   => __( 'Appears in the left sidebar.', 'Beverly' ),
        'class'         => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widgettitle">',
		'after_title'   => '</h2>' ));
}

function beverly_styles() {
	wp_enqueue_style('beverly-style', get_stylesheet_uri());
	wp_enqueue_style('google-fonts', beverly_fonts_url());
	wp_enqueue_style('beverly-genericons', get_template_directory_uri().'/fonts/genericons.css');
	wp_enqueue_style('own-style', '/?own_styles=1');
}

function beverly_scripts() {
	wp_enqueue_script('js-fallback', get_template_directory_uri().'/js/js-fallback.js');
	global $is_IE;
	if($is_IE) wp_enqueue_script('html5shiv',get_template_directory_uri().'/js/html5shiv.js');
	wp_deregister_script('jquery');
	wp_register_script('jquery', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jquery/2.0.0/jquery.min.js", false, '2.0.0');
	wp_enqueue_script('jquery');
	wp_enqueue_script('beverly-script',get_template_directory_uri().'/js/beverly-script.js', array('jquery'), '1.0',true);
	if( !is_singular() && !is_404() ) {
		global $query_string;
		global $wp_query;
		wp_enqueue_script('ajax-script', get_template_directory_uri().'/js/ajax-script.js', array('jquery'), '1.0', true);
		$ajaxInfo = array('query' => $query_string, 'admin_ajax_url' => admin_url('admin-ajax.php'));
		if(get_option('posts_per_page') >= $wp_query->found_posts) $ajaxInfo['stopAjax'] = true;
		wp_localize_script('ajax-script', 'ajaxInfo', $ajaxInfo);
	}
	if ( is_singular() && comments_open() && get_option('thread_comments') ) {
		wp_enqueue_script('comment-reply');
		wp_enqueue_script('comment-toggle',get_template_directory_uri().'/js/comment-toggle.js',array('jquery'), '1.0', true);
	}
	if ( is_home() && beverly_get_sticky_count() ) wp_enqueue_script('sticky', get_template_directory_uri().'/js/sticky.js', array('jquery'), '1.0',true);
	wp_enqueue_script('own-script', '/?own_script=1',array('jquery'),'', get_option('beverly_main_settings')['footer_script']);
}

function beverly_user_own_codes() {
	if ( get_query_var('own_styles') == 1 ) {
		ob_start();
			header( 'Content-type: text/css' );
			$options = get_option( 'beverly_main_settings' );
			$own_styles = beverly_sanitize_css($options['own_styles']);
			echo $own_styles;
			exit;
		ob_clean();
	}
	if ( get_query_var('own_script') == 1 ) {
		ob_start();
			header( 'Content-type: text/javascript' );
			$options = get_option( 'beverly_main_settings' );
			$own_script = $options['own_script'];
			echo $own_script;
			exit;
		ob_clean();
	}
}

function beverly_ajax_posts(){
	global $wp_query;
	global $query_string;
	$query = (isset($_GET['ajax_paged']) ? $_GET['query'] : $query_string);
	query_posts($query);
	$ajax_paged = (isset($_GET['ajax_paged']) ? $_GET['ajax_paged'] : 0);
	$posts_per_page = get_option('posts_per_page');
	$stop_response = "<!--stopAjax-->";
	if(isset($ajax_paged)) {
		$query_paged = get_query_var('paged');
		if($query_paged) $query_paged --;
		$paged = $ajax_paged + $query_paged;
		$max_posts = $wp_query->found_posts;
	} else {
		$paged = (get_query_var('paged') ? get_query_var('paged') : 1);
		$max_posts = $posts_per_page;
	}
	if($paged * $posts_per_page >= $max_posts)
		echo $stop_response;
	query_posts($query."&paged=".$paged."&ignore_sticky_posts=1");
	if ( have_posts() ) {
		while (have_posts() ) {
			the_post();
			get_template_part('content', get_post_format());
		}
	} else {
		echo $stop_response;
		get_template_part('content', 'none');
	}
}

?>
