<?php

function beverly_add_triggers( $vars ) {
	$vars[] = 'own_script';
	$vars[] = 'own_styles';
	return $vars;
}

function beverly_wp_title_filter( $title, $sep ) {
	global $paged, $page;
	if ( is_feed() )
		return $title;
	$title = get_bloginfo( 'name' ).$title;
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'Beverly' ), max( $paged, $page ) );
	return $title;
}

function beverly_content_filter($content) {
	global $is_sticky;
	if(!$content || is_feed()) return $content;
	$content = '<div class = "post-content">'.$content.'</div><div class = "clear"></div>';
	if($is_sticky) return $content;
	if( !is_singular() ) {
		global $post;
		if(post_password_required()) return '';
		if(beverly_get_post_parts()['show_excerpt']) {
			return '<div class = "post-card-cell">'.$content.'</div>';
		}
		return '';
	} else {
	return $content;
	}
}

function beverly_more_link_scroll_remove( $link ) {
	$link = preg_replace( '|#more-[0-9]+|', '', $link );
	return $link;
}

function beverly_thumbnail_filter($html) {
	global $post;
	global $is_sticky;
	if(!is_singular()) {
		if($is_sticky) {
			if(has_post_thumbnail()) {
				return $html;
			} elseif(beverly_has_first_img()) {
				return beverly_get_first_img();
			} else {
				return '<div class = "text-thumbnail">'.get_the_content().'</div>';
			}
		}
		if(beverly_get_post_parts()['show_media']) {
			if(has_post_thumbnail($post->ID)) {
				return '<div class = "media-box"><div class = "glass"></div><a href="'.get_permalink( $post->ID ).'" title="'.esc_attr( get_the_title( $post->ID ) ).'">'.$html.'</a></div>';
			} elseif(beverly_has_first_img()) {
				return '<div class = "media-box"><div class = "glass"></div><a href="'.get_permalink( $post->ID ).'" title="'.esc_attr( get_the_title( $post->ID ) ).'">'.beverly_get_first_img().'</a></div>';
			}
		}
		return '';
	} else {
		return $html;
	}
}

function beverly_author_filter($author) {
	return '<a href = "'.get_author_posts_url(get_the_author_meta('ID')).'" class = "author">'.$author.'</a>';
}

function beverly_date_filter($date) {
	if( is_feed() ) return $date;
	return '<time datetime = "'.date("Y-m-t", strtotime($date)).'">'.$date.'</time>';
}


function beverly_tags_filter($tags) {
		if( is_feed() ) return $tags;
		if( !is_singular() ) {
		global $post;
		if(beverly_get_post_parts()['show_tags'] && $tags) {
			return '<div class = "post-card-cell"><ul class="tags">'.$tags.'</ul></div>';
		}
		return '';
	}
	else {
		return $tags;
	}
}

function beverly_comment_form_filter($defaults) {
	$commenter = wp_get_current_commenter();
	$req = get_option('require_name_email');
	$aria_req = ( $req ? " aria-required='true'" : '' );
	$info_text = ( $req ? __('(required)', 'Beverly') : __('(optional)', 'Beverly') );
	$fields =  array(
	'author' => '<input  ' . ( $req ? 'required="required"' : '' ) . ' id="author" name="author" type="text" placeholder = "Name '.$info_text.'" value="' . esc_attr( $commenter['comment_author'] ) . '" ' . $aria_req . ' />',

	'email' =>
    '<input ' . ( $req ? 'required="required"' : '' ) . ' id="email" name="email" type="email" placeholder = "E-mail '.$info_text.'" value="' . esc_attr( $commenter['comment_author_email'] ) . '" ' . $aria_req . ' />',

	'url' => '<input id="url" name="url" type="url" placeholder = "'.__('Website', 'Beverly').'" value="' . esc_attr( $commenter['comment_author_url'] ) . '" />',
);
	$defaults['fields'] = $fields;
	$defaults['comment_notes_before'] = '';
	$defaults['comment_notes_after'] = '';
	$defaults['comment_field'] = '<textarea placeholder = "'.__('Comment text...', 'Beverly').'" required id="comment" name="comment" cols="45" rows="8" aria-required="true"></textarea>';
	$defaults['title_reply'] = __('Leave a Comment', 'Beverly').'<br/>';
	return $defaults;
}

function beverly_comment_author_filter($author) {
	$user = get_user_by( 'email', get_comment_author_email());
	if($user) {
		return '<a href = "'.get_author_posts_url($user->ID).'">'.$author.'</a>';
	} else {
		if(get_comment_author_url()) return get_comment_author_url_link($author);
		return $author;
	}
}

function beverly_oembed_elements_filter($html, $url, $attr) {
	if ( strpos( $html, "<embed src=" ) !== false ) {
		return str_replace('</param><embed', '</param><param name="wmode" value="opaque"></param><embed wmode="opaque" ', $html);
	} elseif ( strpos ( $html, 'feature=oembed' ) !== false ) {
		return str_replace( 'feature=oembed', 'feature=oembed&wmode=opaque', $html );
	} else {
		return $html;
	}
}

?>